/**
 * Gate API v4
 * APIv4 provides spot, margin and futures trading operations. There are public APIs to retrieve the real-time market statistics, and private APIs which needs authentication to trade on user's behalf.
 *
 *
 * NOTE: This class is auto generated by OpenAPI Generator (https://openapi-generator.tech).
 * https://openapi-generator.tech
 *
 * Do not edit the class manually.
 *
 */

(function(root, factory) {
  if (typeof define === 'function' && define.amd) {
    // AMD. Register as an anonymous module.
    define(['ApiClient', 'model/FundingBookItem', 'model/MarginCurrencyPair'], factory);
  } else if (typeof module === 'object' && module.exports) {
    // CommonJS-like environments that support module.exports, like Node.
    module.exports = factory(require('../ApiClient'), require('../model/FundingBookItem'), require('../model/MarginCurrencyPair'));
  } else {
    // Browser globals (root is window)
    if (!root.GateApi) {
      root.GateApi = {};
    }
    root.GateApi.MarginApi = factory(root.GateApi.ApiClient, root.GateApi.FundingBookItem, root.GateApi.MarginCurrencyPair);
  }
}(this, function(ApiClient, FundingBookItem, MarginCurrencyPair) {
  'use strict';

  /**
   * Margin service.
   * @module api/MarginApi
   */

  /**
   * Constructs a new MarginApi. 
   * @alias module:api/MarginApi
   * @class
   * @param {module:ApiClient} [apiClient] Optional API client implementation to use,
   * default to {@link module:ApiClient#instance} if unspecified.
   */
  var exports = function(apiClient) {
    this.apiClient = apiClient || ApiClient.instance;


    /**
     * Callback function to receive the result of the listMarginCurrencyPairs operation.
     * @callback module:api/MarginApi~listMarginCurrencyPairsCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/MarginCurrencyPair>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * List all supported currency pairs supported in margin trading
     * @param {module:api/MarginApi~listMarginCurrencyPairsCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/MarginCurrencyPair>}
     */
    this.listMarginCurrencyPairs = function(callback) {
      var postBody = null;

      var pathParams = {
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [MarginCurrencyPair];
      return this.apiClient.callApi(
        '/margin/currency_pairs', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null, callback
      );
    }

    /**
     * Callback function to receive the result of the getMarginCurrencyPair operation.
     * @callback module:api/MarginApi~getMarginCurrencyPairCallback
     * @param {String} error Error message, if any.
     * @param {module:model/MarginCurrencyPair} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Query one single margin currency pair
     * @param {String} currencyPair Margin currency pair
     * @param {module:api/MarginApi~getMarginCurrencyPairCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link module:model/MarginCurrencyPair}
     */
    this.getMarginCurrencyPair = function(currencyPair, callback) {
      var postBody = null;
      // verify the required parameter 'currencyPair' is set
      if (currencyPair === undefined || currencyPair === null) {
        throw new Error("Missing the required parameter 'currencyPair' when calling getMarginCurrencyPair");
      }

      var pathParams = {
        'currency_pair': currencyPair
      };
      var queryParams = {
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = MarginCurrencyPair;
      return this.apiClient.callApi(
        '/margin/currency_pairs/{currency_pair}', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null, callback
      );
    }

    /**
     * Callback function to receive the result of the listFundingBook operation.
     * @callback module:api/MarginApi~listFundingBookCallback
     * @param {String} error Error message, if any.
     * @param {Array.<module:model/FundingBookItem>} data The data returned by the service call.
     * @param {String} response The complete HTTP response.
     */

    /**
     * Order book of lending loans
     * @param {String} currency Retrieved specified currency related data
     * @param {module:api/MarginApi~listFundingBookCallback} callback The callback function, accepting three arguments: error, data, response
     * data is of type: {@link Array.<module:model/FundingBookItem>}
     */
    this.listFundingBook = function(currency, callback) {
      var postBody = null;
      // verify the required parameter 'currency' is set
      if (currency === undefined || currency === null) {
        throw new Error("Missing the required parameter 'currency' when calling listFundingBook");
      }

      var pathParams = {
      };
      var queryParams = {
        'currency': currency,
      };
      var collectionQueryParams = {
      };
      var headerParams = {
      };
      var formParams = {
      };

      var authNames = [];
      var contentTypes = [];
      var accepts = ['application/json'];
      var returnType = [FundingBookItem];
      return this.apiClient.callApi(
        '/margin/funding_book', 'GET',
        pathParams, queryParams, collectionQueryParams, headerParams, formParams, postBody,
        authNames, contentTypes, accepts, returnType, null, callback
      );
    }
  };

  return exports;
}));
